#ifndef E_MOD_MAIN_H
#define E_MOD_MAIN_H

E_Config_Dialog *e_int_config_shelf(E_Container *con, const char *params __UNUSED__);

/**
 * @addtogroup Optional_Conf
 * @{
 *
 * @defgroup Module_Conf_Shelves Shelves (Panels) Configuration
 *
 * Configure shelves (panels) that exist on screen. They may be
 * horizontal or vertical, exist on top of below windows and usually
 * contain sequence of @ref Optional_Gadgets.
 *
 * @}
 */
#endif
